@@ -75,7 +75,7 @@ def obs_fn(env: Env, state: State) -> Obs:  # return info about neighbors ---
     idxs, dist = jk.extras.query_neighbors_pairwise(state.pos, state.pos, k=env.cfg.knn)
     mask: Array = dist < env.sight[env.types[idxs][:, 0]][..., None] | (state.hp[idxs] > 0)
     pos: Array = (state.pos[idxs] - state.pos[:, None, ...]).at[:, 0, :].set(state.pos) * mask[..., None]
-    args = state.hp, env.types, env.teams, env.reach, env.sight, env.speed
+    args: Tuple = (state.hp, env.types, env.teams, env.reach[env.types], env.sight[env.types], env.speed[env.types])
     hp, type, team, reach, sight, speed = map(lambda x: x[idxs] * mask, args)
     return Obs(
         pos=pos, dist=dist, hp=hp, type=type, team=team, reach=reach, sight=sight, speed=speed, mask=mask, idx=idxs * mask
