@@ -5,9 +5,6 @@
 # imports
 from chex import dataclass
 from jaxtyping import Array, Bool
-from jax import lax
-import jax.numpy as jnp
-# from parabellum.geo import geography_fn
 
 
 @dataclass
